@@ -42,13 +42,10 @@ import QuanticsTensorTrainMat
 from QuanticsTensorTrainMat import *
 import SpectralTensorTrain 
 from SpectralTensorTrain import *
-import mpi_eval
-from mpi_eval import *
 
 __all__ = []
 __all__ += aux.__all__
 __all__ += tensor_wrapper.__all__
-__all__ += mpi_eval.__all__
 __all__ += candecomp.__all__
 __all__ += TensorTrainVec.__all__
 __all__ += TensorTrainMat.__all__
