@@ -32,26 +32,12 @@ import time
 import TensorToolbox as DT
 import TensorToolbox.multilinalg as mla
 
+from aux import bcolors
+
 plt.close('all')
 RUNTESTS = [0,1,2,3,4,5,7]
 PLOTTING = False
 
-class bcolors:
-    HEADER = '\033[95m'
-    OKBLUE = '\033[94m'
-    OKGREEN = '\033[92m'
-    WARNING = '\033[93m'
-    FAIL = '\033[91m'
-    ENDC = '\033[0m'
-
-    def disable(self):
-        self.HEADER = ''
-        self.OKBLUE = ''
-        self.OKGREEN = ''
-        self.WARNING = ''
-        self.FAIL = ''
-        self.ENDC = ''
-
 def print_ok(string):
     print bcolors.OKGREEN + "[SUCCESS] " + string + bcolors.ENDC
 
